@@ -1,13 +1,13 @@
 'use strict';
-
-var Promise = global.InternalPromise;
-var internalThen = require('./internal-then');
+/* eslint no-undef: 0 */
+const Promise = global.InternalPromise;
+const internalThen = require('./internal-then');
 
 module.exports = Promise.resolve().then(function outer() {
 	return Promise.resolve().then(function inner() {
 		return Promise.resolve().then(function evenMoreInner() {
 			return Promise.resolve().then(function mostInner() {
-				a.b.c.d()
+				a.b.c.d();
 			}).catch(function catcher(e) {
 				return e.stack;
 			});
@@ -19,7 +19,7 @@ module.exports.middle = Promise.resolve().then(function outer() {
 	return Promise.resolve().then(function inner() {
 		return internalThen(function evenMoreInner() {
 			return Promise.resolve().then(function mostInner() {
-				a.b.c.d()
+				a.b.c.d();
 			}).catch(function catcher(e) {
 				return e.stack;
 			});
@@ -40,11 +40,11 @@ module.exports.bottom = new Promise(function (resolve) {
 		return Promise.resolve().then(function inner() {
 			return Promise.resolve().then(function evenMoreInner() {
 				return Promise.resolve().then(function mostInner() {
-					a.b.c.d()
+					a.b.c.d();
 				}).catch(function catcher(e) {
 					resolve(e.stack);
 				});
 			});
 		});
-	}),0);
+	}), 0);
 });
